Options used by the reviewer package
reviewer_options.RdThe reviewer package makes use of the following user-facing options:
reviewer.clientsupplies the underlying LLM powering the reviewer. Theclientargument toreview()takes precedence over this option when provided. The option can be either:An ellmer::Chat object (e.g.,
ellmer::chat_claude())A model string in
"provider/model"format as described inellmer::chat()(e.g.,"openai/gpt-5.2")
Typically set in your
.Rprofile:reviewer.pending_editscontrols the maximum number of pending edits allowed at once before the model waits for user responses. Themax_pendingargument toreview()takes precedence over this option when provided. The option must be a positive integer. Higher values reduce wait time but may feel more overwhelming and risk edit conflicts. Defaults to 2.Typically set in your
.Rprofile:reviewer.memoryspecifies the path to a file where reviewer stores user preferences learned from accepted/rejected edits. When set, reviewer uses this file without prompting. When not set, reviewer will ask for permission to write to~/.config/reviewer/memory.mdon first launch.Typically set in your
.Rprofile: